# frozen_string_literal: true

# exemple d'utilisation
=begin
ha = Hermes::HousingApplication.first
so=Hermes::BoClient::ApplicationTask.new(
    {
                                                 housing_request_id: ha.housing_request_id,
                                                 housing_offer_id: ha.housing_offer_id,
                                             }
)
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end

module Hermes
  module BoClient
    class DeletePJTask < BaseTask
      
      def initialize(options = {})
        @xsd = 'supprimerPJ.xsd'
        super(options)
      end
      
      endpoint {'ws/rest/als/demande/v1/pieceJustificative/supprimer'}
      
      task_name 'application'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingRequestMap'
      params *%i[
      numUnique
      ]
      
      def to_xml
        namespaces = {
          'xmlns:ns2' => 'http://v1.als.ikos.webservice.immobilier.sopra/pieceJustificative'
        }
        
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
          b['ns2'].supprimerPJ(namespaces) do
            b.numUnique mapping.numUnique do
              b.parent.namespace = nil
            end
            b.guichet mapping.numGuichet do
              b.parent.namespace = nil
            end
            b.pieceID mapping.idPiece do
              b.parent.namespace = nil
            end
          end
        end
        builder.to_xml
      end
    end
  end
end
