# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'


# exemple d'utilisation
# hr = Hermes::HousingRequest.first
# ho= Hermes::HousingOffer.first
# so=Hermes::BoClient::UpdateStatusTask.new({:'housing_request_id'=> hr.id,housing_offer_id: ho.id})
# so.to_xml
# so.execute

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'RechercheDemande.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::FindNudTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
  let!(:dc_channel) {create(:housing_channel, key: 'dc')}
 

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:housing_request_initializer1) do
      create(:housing_request_initializer, unique_number: "1110220019793G1175")
    end
  
    let!(:find_nud_task1) do
      build(
        :find_nud_task,
        options: { housing_request_initializer_id: housing_request_initializer1.id.to_s }
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        expect(xsd.validate(Nokogiri::XML(find_nud_task1.to_xml))).to eq([])
        xmlres = ""
        find_nud_task1.execute
        VCR.use_cassette("find_nud_task1", :match_requests_on => [:method, :uri, :path]) do
          perform_enqueued_jobs do
            jobs = enqueued_jobs.select{ |job| job[:job] == ExecuteSopraTaskJob }
            jobs.each {|job| xmlres = job[:job].perform_now(*job[:args])}
          end
        end
        hri = Hermes::HousingRequestInitializer.create(unique_number: "ee")
        xml_model = Hermes::Xml.create(xml: xmlres, object_id: hri.id)
        hri.update(xml: xml_model)
        hri.hydrate_housing_request_from_sne(user1.id)
        expect(hri.housing_request_id).not_to be(nil)
      

        expect(housing_request_initializer1.reload.last_send_has_error).to eq(nil)
      end
    end
  end
end
